@@ -11,8 +11,8 @@ def define_job(
     destination_key,
     trigger_name,
     trigger_type,
-    trigger_definition,
-    job_configuration,
+    trigger_definition={},
+    job_configuration={},
     python_version="3",
     aws_access_key=None,
     aws_secret_key=None,
@@ -49,14 +49,14 @@ def define_job(
     glueclient = boto3.client(
         "glue",
         aws_access_key_id=aws_access_key_id,
-        aws_secret_key=aws_secret_key_id,
+        aws_secret_access_key=aws_secret_key_id,
         region_name=region_name,
     )
 
     s3client = boto3.client(
         "s3",
         aws_access_key_id=aws_access_key_id,
-        aws_secret_key=aws_secret_key_id,
+        aws_secret_access_key=aws_secret_key_id,
         region_name=region_name,
     )
 
@@ -95,30 +95,33 @@ def handle_job(
     destination_key,
     role_arn,
     python_version,
-    job_configuration,
+    job_configuration={},
 ):
     """
     Sets up the job in AWS Glue or updates it if it already exists.
     """
+
+    command_object = {
+        "Name": command,
+        "ScriptLocation": destination_key,
+        "PythonVersion": python_version,
+    }
+
     if new_job:
         response = glueclient.create_job(
             Name=name,
             Role=role_arn,
-            Command={
-                "Name": command,
-                "ScriptLocation": destination_key,
-                "PythonVersion": python_version,
-            },
+            Command=command_object,
         )
 
+    job_configuration["Command"] = command_object
+
     response = glueclient.update_job(JobName=name, JobUpdate=job_configuration)
 
     return response
 
 
-def handle_script_upload(
-    s3client, file_location, destination_key, glue_script_bucket
-):
+def handle_script_upload(s3client, file_location, destination_key, glue_script_bucket):
     """
     Uploads the Glue Job script to the S3 bucket, and creates the necessary environment bucket if it doesn't exist.
     """
